/*
 * CrudContainer
 * Copyright (C) 2011 by Apaq
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package dk.apaq.filter.sort;

import dk.apaq.filter.FiltrationItem;
import java.util.Arrays;
import java.util.List;

/**
 * A sorter that specifies how sorting of data.
 */
public class Sorter {

    private final List<SorterEntry> elements;

    /**
     * Creates a new instance with the specified elements.
     * @param elements The sorterentires for this sorter.
     */
    public Sorter(List<SorterEntry> elements) {
        this.elements = elements;
    }

    /**
     * Creates a new instance with the specified elements.
     * @param elements The sorterentires for this sorter.
     */
    public Sorter(SorterEntry ... entries) {
        this(Arrays.asList(entries));
    }

    /**
     * Creates a new sorter that sorts on a single property. The sorting
     * direction will be ascending.
     * @param propertyId The propertyId to use for sorting.
     */
    public Sorter(String propertyId) {
        this(propertyId, SortDirection.Ascending);
    }

    /**
     * Creates a new sorter that sorts on a single property.
     * @param propertyId The propertyId to use for sorting.
     * @param direction The direction for the sorting.
     */
    public Sorter(String propertyId, SortDirection direction) {
        this(new SorterEntry(propertyId, direction));
    }

    /**
     * Retrieve Sorter entries.
     * @return The sorter entires.
     */
    public List<SorterEntry> getSorterEntries() {
        return elements;
    }

    /**
     * Compare 2 items using this sorter.
     * @param filterItem1 The first item.
     * @param filterItem2 The second item.
     * @return The result.
     */
    public SortResult compare(FiltrationItem filterItem1, FiltrationItem filterItem2) {
        for(SorterEntry sorter:elements) {
            SortResult result = sorter.compare(filterItem1, filterItem2);
            if(result != SortResult.Equal) {
                return result;
            }
        }
        return SortResult.Equal;
    }

    
}
